!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ################
      MODULE MODD_DATA_BEM_n
!     ################
!
!!****  *MODD_DATA_BEM_n - declaration of surface parameters for BEM
!!
!!    PURPOSE
!!    -------
!     Declaration of surface parameters
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	G. Pigeon   *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       08/2011
!
!*       0.   DECLARATIONS
!             ------------
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE DATA_BEM_t
  !
  LOGICAL :: LDATA_TCOOL_TARGET 
  LOGICAL :: LDATA_THEAT_TARGET 
  LOGICAL :: LDATA_F_WASTE_CAN   
  LOGICAL :: LDATA_EFF_HEAT   
  LOGICAL :: LDATA_HC_FLOOR     
  LOGICAL :: LDATA_TC_FLOOR     
  LOGICAL :: LDATA_D_FLOOR 
  LOGICAL :: LDATA_QIN          
  LOGICAL :: LDATA_QIN_FRAD     
  LOGICAL :: LDATA_SHGC         
  LOGICAL :: LDATA_U_WIN        
  LOGICAL :: LDATA_GR           
  LOGICAL :: LDATA_SHGC_SH
  LOGICAL :: LDATA_FLOOR_HEIGHT 
  LOGICAL :: LDATA_INF  
  LOGICAL :: LDATA_F_WATER_COND  
  LOGICAL :: LDATA_SHADE
  LOGICAL :: LDATA_NATVENT
  LOGICAL :: LDATA_QIN_FLAT     
  LOGICAL :: LDATA_HR_TARGET    
  LOGICAL :: LDATA_V_VENT   
  LOGICAL :: LDATA_CAP_SYS_HEAT 
  LOGICAL :: LDATA_CAP_SYS_RAT  
  LOGICAL :: LDATA_T_ADP        
  LOGICAL :: LDATA_M_SYS_RAT    
  LOGICAL :: LDATA_COP_RAT      
  LOGICAL :: LDATA_T_SIZE_MAX    
  LOGICAL :: LDATA_T_SIZE_MIN  
!
! Number of layers in the specification of thermal characteristics
!
  INTEGER                    :: NPAR_FLOOR_LAYER   ! number of layers in roofs
!
!
! Parameters:
!
  REAL, POINTER, DIMENSION(:)   :: XPAR_TCOOL_TARGET ! cooling setpoint of indoor air
  REAL, POINTER, DIMENSION(:)   :: XPAR_THEAT_TARGET ! heating setpoint of indoor air
  REAL, POINTER, DIMENSION(:)   :: XPAR_F_WASTE_CAN  ! fraction of waste heat into the canyon
  REAL, POINTER, DIMENSION(:)   :: XPAR_EFF_HEAT     ! efficiency of the heating system
  REAL, POINTER, DIMENSION(:,:) :: XPAR_HC_FLOOR     ! heat capacity of floor layers [J m-3 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XPAR_TC_FLOOR     ! thermal conductivity of floor layers [W m-1 K-1]
  REAL, POINTER, DIMENSION(:,:) :: XPAR_D_FLOOR      ! thickness of floor layers [m]
  REAL, POINTER, DIMENSION(:)   :: XPAR_QIN          ! internal heat gains [W m-2(floor)]
  REAL, POINTER, DIMENSION(:)   :: XPAR_QIN_FRAD     ! radiant fraction of internal heat gains
  REAL, POINTER, DIMENSION(:)   :: XPAR_SHGC         ! solar transmitance of windows
  REAL, POINTER, DIMENSION(:)   :: XPAR_U_WIN        ! glazing thermal resistance [K m W-2]
  REAL, POINTER, DIMENSION(:)   :: XPAR_GR           ! glazing ratio
  REAL, POINTER, DIMENSION(:)   :: XPAR_SHGC_SH      ! solar transmitance of windows + shading
  REAL, POINTER, DIMENSION(:)   :: XPAR_FLOOR_HEIGHT ! building floor height [m]
  REAL, POINTER, DIMENSION(:)   :: XPAR_INF          ! infiltration/ventilation flow rate [AC/H]
!
  REAL, POINTER, DIMENSION(:)   :: XPAR_F_WATER_COND ! fraction of evaporation for condensers
  REAL, POINTER, DIMENSION(:)   :: XPAR_SHADE        ! Flag to activate shading devices 0->inactivated , 1->activated
  REAL, POINTER, DIMENSION(:)   :: XPAR_NATVENT      ! Flag to describe bld surventilation solution 0-> NONE ; 1 -> MANU ; 2-> AUTO
  REAL, POINTER, DIMENSION(:)   :: XPAR_QIN_FLAT     ! Latent franction of internal heat gains
  REAL, POINTER, DIMENSION(:)   :: XPAR_HR_TARGET    ! Relative humidity setpoint
  REAL, POINTER, DIMENSION(:)   :: XPAR_V_VENT       ! Ventilation flow rate [AC/H]
  REAL, POINTER, DIMENSION(:)   :: XPAR_CAP_SYS_HEAT ! Capacity of the heating system 
                                                     ! [W m-2(bld)]
  REAL, POINTER, DIMENSION(:)   :: XPAR_CAP_SYS_RAT  ! Rated capacity of the cooling system
                                                     ! [W m-2(bld)]
  REAL, POINTER, DIMENSION(:)   :: XPAR_T_ADP        ! Apparatus dewpoint temperature of the
                                                     ! cooling coil [K]
  REAL, POINTER, DIMENSION(:)   :: XPAR_M_SYS_RAT    ! Rated HVAC mass flow rate 
                                                     ! [kg s-1 m-2(bld)]
  REAL, POINTER, DIMENSION(:)   :: XPAR_COP_RAT      ! Rated COP of the cooling system
  REAL, POINTER, DIMENSION(:)   :: XPAR_T_SIZE_MAX   ! 
  REAL, POINTER, DIMENSION(:)   :: XPAR_T_SIZE_MIN   ! 
!
END TYPE DATA_BEM_t

TYPE(DATA_BEM_t), ALLOCATABLE, TARGET, SAVE :: DATA_BEM_MODEL(:)
!
LOGICAL, POINTER :: LDATA_TCOOL_TARGET=>NULL()
!$OMP THREADPRIVATE(LDATA_TCOOL_TARGET)
LOGICAL, POINTER :: LDATA_THEAT_TARGET=>NULL()
!$OMP THREADPRIVATE(LDATA_THEAT_TARGET)
LOGICAL, POINTER :: LDATA_F_WASTE_CAN=>NULL()   
!$OMP THREADPRIVATE(LDATA_F_WASTE_CAN)
LOGICAL, POINTER :: LDATA_EFF_HEAT=>NULL()   
!$OMP THREADPRIVATE(LDATA_EFF_HEAT)
LOGICAL, POINTER :: LDATA_HC_FLOOR=>NULL()     
!$OMP THREADPRIVATE(LDATA_HC_FLOOR)
LOGICAL, POINTER :: LDATA_TC_FLOOR=>NULL()     
!$OMP THREADPRIVATE(LDATA_TC_FLOOR)
LOGICAL, POINTER :: LDATA_D_FLOOR=>NULL() 
!$OMP THREADPRIVATE(LDATA_D_FLOOR)
LOGICAL, POINTER :: LDATA_QIN=>NULL()       
!$OMP THREADPRIVATE(LDATA_QIN)
LOGICAL, POINTER :: LDATA_QIN_FRAD=>NULL()   
!$OMP THREADPRIVATE(LDATA_QIN_FRAD)
LOGICAL, POINTER :: LDATA_SHGC=>NULL()       
!$OMP THREADPRIVATE(LDATA_SHGC)
LOGICAL, POINTER :: LDATA_U_WIN=>NULL()      
!$OMP THREADPRIVATE(LDATA_U_WIN)
LOGICAL, POINTER :: LDATA_GR=>NULL()          
!$OMP THREADPRIVATE(LDATA_GR)
LOGICAL, POINTER :: LDATA_SHGC_SH=>NULL()
!$OMP THREADPRIVATE(LDATA_SHGC_SH)
LOGICAL, POINTER :: LDATA_FLOOR_HEIGHT=>NULL() 
!$OMP THREADPRIVATE(LDATA_FLOOR_HEIGHT)
LOGICAL, POINTER :: LDATA_INF=>NULL()  
!$OMP THREADPRIVATE(LDATA_INF)
LOGICAL, POINTER :: LDATA_F_WATER_COND=>NULL()  
!$OMP THREADPRIVATE(LDATA_F_WATER_COND)
LOGICAL, POINTER :: LDATA_SHADE=>NULL()
!$OMP THREADPRIVATE(LDATA_SHADE)
LOGICAL, POINTER :: LDATA_NATVENT=>NULL()
!$OMP THREADPRIVATE(LDATA_NATVENT)
LOGICAL, POINTER :: LDATA_QIN_FLAT=>NULL()     
!$OMP THREADPRIVATE(LDATA_QIN_FLAT)
LOGICAL, POINTER :: LDATA_HR_TARGET=>NULL()    
!$OMP THREADPRIVATE(LDATA_HR_TARGET)
LOGICAL, POINTER :: LDATA_V_VENT=>NULL()   
!$OMP THREADPRIVATE(LDATA_V_VENT)
LOGICAL, POINTER :: LDATA_CAP_SYS_HEAT=>NULL() 
!$OMP THREADPRIVATE(LDATA_CAP_SYS_HEAT)
LOGICAL, POINTER :: LDATA_CAP_SYS_RAT=>NULL()  
!$OMP THREADPRIVATE(LDATA_CAP_SYS_RAT)
LOGICAL, POINTER :: LDATA_T_ADP=>NULL()        
!$OMP THREADPRIVATE(LDATA_T_ADP)
LOGICAL, POINTER :: LDATA_M_SYS_RAT=>NULL()    
!$OMP THREADPRIVATE(LDATA_M_SYS_RAT)
LOGICAL, POINTER :: LDATA_COP_RAT=>NULL()      
!$OMP THREADPRIVATE(LDATA_COP_RAT)
LOGICAL, POINTER :: LDATA_T_SIZE_MAX=>NULL()    
!$OMP THREADPRIVATE(LDATA_T_SIZE_MAX)
LOGICAL, POINTER :: LDATA_T_SIZE_MIN=>NULL()  
!$OMP THREADPRIVATE(LDATA_T_SIZE_MIN)
INTEGER, POINTER :: NPAR_FLOOR_LAYER=>NULL()
!$OMP THREADPRIVATE(NPAR_FLOOR_LAYER)
REAL, POINTER, DIMENSION(:)   :: XPAR_TCOOL_TARGET=>NULL()
!$OMP THREADPRIVATE(XPAR_TCOOL_TARGET)
REAL, POINTER, DIMENSION(:)   :: XPAR_THEAT_TARGET=>NULL()
!$OMP THREADPRIVATE(XPAR_THEAT_TARGET)
REAL, POINTER, DIMENSION(:)   :: XPAR_F_WASTE_CAN=>NULL()
!$OMP THREADPRIVATE(XPAR_F_WASTE_CAN)
REAL, POINTER, DIMENSION(:)   :: XPAR_EFF_HEAT=>NULL()
!$OMP THREADPRIVATE(XPAR_EFF_HEAT)
REAL, POINTER, DIMENSION(:,:) :: XPAR_HC_FLOOR=>NULL()
!$OMP THREADPRIVATE(XPAR_HC_FLOOR)
REAL, POINTER, DIMENSION(:,:) :: XPAR_TC_FLOOR=>NULL()
!$OMP THREADPRIVATE(XPAR_TC_FLOOR)
REAL, POINTER, DIMENSION(:,:) :: XPAR_D_FLOOR=>NULL()
!$OMP THREADPRIVATE(XPAR_D_FLOOR)
REAL, POINTER, DIMENSION(:)   :: XPAR_QIN=>NULL()
!$OMP THREADPRIVATE(XPAR_QIN)
REAL, POINTER, DIMENSION(:)   :: XPAR_QIN_FRAD=>NULL()
!$OMP THREADPRIVATE(XPAR_QIN_FRAD)
REAL, POINTER, DIMENSION(:)   :: XPAR_SHGC=>NULL()
!$OMP THREADPRIVATE(XPAR_SHGC)
REAL, POINTER, DIMENSION(:)   :: XPAR_U_WIN=>NULL()
!$OMP THREADPRIVATE(XPAR_U_WIN)
REAL, POINTER, DIMENSION(:)   :: XPAR_GR=>NULL()
!$OMP THREADPRIVATE(XPAR_GR)
REAL, POINTER, DIMENSION(:)   :: XPAR_SHGC_SH=>NULL()
!$OMP THREADPRIVATE(XPAR_SHGC_SH)
REAL, POINTER, DIMENSION(:)   :: XPAR_FLOOR_HEIGHT=>NULL()
!$OMP THREADPRIVATE(XPAR_FLOOR_HEIGHT)
REAL, POINTER, DIMENSION(:)   :: XPAR_INF=>NULL()
!$OMP THREADPRIVATE(XPAR_INF)
REAL, POINTER, DIMENSION(:):: XPAR_SHADE=>NULL()
!$OMP THREADPRIVATE(XPAR_SHADE)
REAL, POINTER, DIMENSION(:) :: XPAR_NATVENT=>NULL()
!$OMP THREADPRIVATE(XPAR_NATVENT)
REAL, POINTER, DIMENSION(:)   :: XPAR_F_WATER_COND=>NULL()
!$OMP THREADPRIVATE(XPAR_F_WATER_COND)
REAL, POINTER, DIMENSION(:)   :: XPAR_QIN_FLAT=>NULL()
!$OMP THREADPRIVATE(XPAR_QIN_FLAT)
REAL, POINTER, DIMENSION(:)   :: XPAR_HR_TARGET=>NULL()
!$OMP THREADPRIVATE(XPAR_HR_TARGET)
REAL, POINTER, DIMENSION(:)   :: XPAR_V_VENT=>NULL()
!$OMP THREADPRIVATE(XPAR_V_VENT)
REAL, POINTER, DIMENSION(:)   :: XPAR_CAP_SYS_HEAT=>NULL()
!$OMP THREADPRIVATE(XPAR_CAP_SYS_HEAT)
REAL, POINTER, DIMENSION(:)   :: XPAR_CAP_SYS_RAT=>NULL()
!$OMP THREADPRIVATE(XPAR_CAP_SYS_RAT)
REAL, POINTER, DIMENSION(:)   :: XPAR_T_ADP=>NULL()
!$OMP THREADPRIVATE(XPAR_T_ADP)
REAL, POINTER, DIMENSION(:)   :: XPAR_M_SYS_RAT=>NULL()
!$OMP THREADPRIVATE(XPAR_M_SYS_RAT)
REAL, POINTER, DIMENSION(:)   :: XPAR_COP_RAT=>NULL()
!$OMP THREADPRIVATE(XPAR_COP_RAT)
REAL, POINTER, DIMENSION(:)   :: XPAR_T_SIZE_MAX=>NULL()
!$OMP THREADPRIVATE(XPAR_T_SIZE_MAX)
REAL, POINTER, DIMENSION(:)   :: XPAR_T_SIZE_MIN=>NULL()
!$OMP THREADPRIVATE(XPAR_T_SIZE_MIN)
!
CONTAINS

SUBROUTINE DATA_BEM_GOTO_MODEL(KFROM, KTO, LKFROM)
INTEGER, INTENT(IN) :: KFROM, KTO
LOGICAL, INTENT(IN) :: LKFROM
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
! Save current state for allocated arrays
!
IF (LKFROM) THEN
DATA_BEM_MODEL(KFROM)%XPAR_TCOOL_TARGET=>XPAR_TCOOL_TARGET
DATA_BEM_MODEL(KFROM)%XPAR_THEAT_TARGET=>XPAR_THEAT_TARGET
DATA_BEM_MODEL(KFROM)%XPAR_F_WASTE_CAN=>XPAR_F_WASTE_CAN
DATA_BEM_MODEL(KFROM)%XPAR_EFF_HEAT=>XPAR_EFF_HEAT
DATA_BEM_MODEL(KFROM)%XPAR_HC_FLOOR=>XPAR_HC_FLOOR
DATA_BEM_MODEL(KFROM)%XPAR_TC_FLOOR=>XPAR_TC_FLOOR
DATA_BEM_MODEL(KFROM)%XPAR_D_FLOOR=>XPAR_D_FLOOR
DATA_BEM_MODEL(KFROM)%XPAR_QIN=>XPAR_QIN
DATA_BEM_MODEL(KFROM)%XPAR_QIN_FRAD=>XPAR_QIN_FRAD
DATA_BEM_MODEL(KFROM)%XPAR_SHGC=>XPAR_SHGC
DATA_BEM_MODEL(KFROM)%XPAR_U_WIN=>XPAR_U_WIN
DATA_BEM_MODEL(KFROM)%XPAR_GR=>XPAR_GR
DATA_BEM_MODEL(KFROM)%XPAR_SHGC_SH=>XPAR_SHGC_SH
DATA_BEM_MODEL(KFROM)%XPAR_FLOOR_HEIGHT=>XPAR_FLOOR_HEIGHT
DATA_BEM_MODEL(KFROM)%XPAR_INF=>XPAR_INF
!
DATA_BEM_MODEL(KFROM)%XPAR_QIN_FLAT=>XPAR_QIN_FLAT
DATA_BEM_MODEL(KFROM)%XPAR_HR_TARGET=>XPAR_HR_TARGET
DATA_BEM_MODEL(KFROM)%XPAR_V_VENT=>XPAR_V_VENT
DATA_BEM_MODEL(KFROM)%XPAR_CAP_SYS_HEAT=>XPAR_CAP_SYS_HEAT
DATA_BEM_MODEL(KFROM)%XPAR_CAP_SYS_RAT=>XPAR_CAP_SYS_RAT
DATA_BEM_MODEL(KFROM)%XPAR_T_ADP=>XPAR_T_ADP
DATA_BEM_MODEL(KFROM)%XPAR_M_SYS_RAT=>XPAR_M_SYS_RAT
DATA_BEM_MODEL(KFROM)%XPAR_COP_RAT=>XPAR_COP_RAT
DATA_BEM_MODEL(KFROM)%XPAR_T_SIZE_MAX=>XPAR_T_SIZE_MAX
DATA_BEM_MODEL(KFROM)%XPAR_T_SIZE_MIN=>XPAR_T_SIZE_MIN
DATA_BEM_MODEL(KFROM)%XPAR_F_WATER_COND=>XPAR_F_WATER_COND
DATA_BEM_MODEL(KFROM)%XPAR_SHADE=>XPAR_SHADE
DATA_BEM_MODEL(KFROM)%XPAR_NATVENT=>XPAR_NATVENT
ENDIF
!
! Current model is set to model KTO
!
IF (LHOOK) CALL DR_HOOK('MODD_DATA_BEM_N:DATA_BEM_GOTO_MODEL',0,ZHOOK_HANDLE)
LDATA_TCOOL_TARGET=>DATA_BEM_MODEL(KTO)%LDATA_TCOOL_TARGET
LDATA_THEAT_TARGET=>DATA_BEM_MODEL(KTO)%LDATA_THEAT_TARGET
LDATA_F_WASTE_CAN=>DATA_BEM_MODEL(KTO)%LDATA_F_WASTE_CAN
LDATA_EFF_HEAT=>DATA_BEM_MODEL(KTO)%LDATA_EFF_HEAT
LDATA_HC_FLOOR=>DATA_BEM_MODEL(KTO)%LDATA_HC_FLOOR
LDATA_TC_FLOOR=>DATA_BEM_MODEL(KTO)%LDATA_TC_FLOOR
LDATA_D_FLOOR=>DATA_BEM_MODEL(KTO)%LDATA_D_FLOOR
LDATA_QIN=>DATA_BEM_MODEL(KTO)%LDATA_QIN
LDATA_QIN_FRAD=>DATA_BEM_MODEL(KTO)%LDATA_QIN_FRAD
LDATA_SHGC=>DATA_BEM_MODEL(KTO)%LDATA_SHGC
LDATA_U_WIN=>DATA_BEM_MODEL(KTO)%LDATA_U_WIN
LDATA_GR=>DATA_BEM_MODEL(KTO)%LDATA_GR
LDATA_SHGC_SH=>DATA_BEM_MODEL(KTO)%LDATA_SHGC_SH
LDATA_FLOOR_HEIGHT=>DATA_BEM_MODEL(KTO)%LDATA_FLOOR_HEIGHT
LDATA_INF=>DATA_BEM_MODEL(KTO)%LDATA_INF
LDATA_F_WATER_COND=>DATA_BEM_MODEL(KTO)%LDATA_F_WATER_COND
LDATA_SHADE=>DATA_BEM_MODEL(KTO)%LDATA_SHADE
LDATA_NATVENT=>DATA_BEM_MODEL(KTO)%LDATA_NATVENT
LDATA_QIN_FLAT=>DATA_BEM_MODEL(KTO)%LDATA_QIN_FLAT
LDATA_HR_TARGET=>DATA_BEM_MODEL(KTO)%LDATA_HR_TARGET
LDATA_V_VENT=>DATA_BEM_MODEL(KTO)%LDATA_V_VENT
LDATA_CAP_SYS_HEAT=>DATA_BEM_MODEL(KTO)%LDATA_CAP_SYS_HEAT
LDATA_CAP_SYS_RAT=>DATA_BEM_MODEL(KTO)%LDATA_CAP_SYS_RAT
LDATA_T_ADP=>DATA_BEM_MODEL(KTO)%LDATA_T_ADP
LDATA_M_SYS_RAT=>DATA_BEM_MODEL(KTO)%LDATA_M_SYS_RAT
LDATA_COP_RAT=>DATA_BEM_MODEL(KTO)%LDATA_COP_RAT
LDATA_T_SIZE_MAX=>DATA_BEM_MODEL(KTO)%LDATA_T_SIZE_MAX
LDATA_T_SIZE_MIN=>DATA_BEM_MODEL(KTO)%LDATA_T_SIZE_MIN
NPAR_FLOOR_LAYER=>DATA_BEM_MODEL(KTO)%NPAR_FLOOR_LAYER
XPAR_TCOOL_TARGET=>DATA_BEM_MODEL(KTO)%XPAR_TCOOL_TARGET
XPAR_THEAT_TARGET=>DATA_BEM_MODEL(KTO)%XPAR_THEAT_TARGET
XPAR_F_WASTE_CAN=>DATA_BEM_MODEL(KTO)%XPAR_F_WASTE_CAN
XPAR_EFF_HEAT=>DATA_BEM_MODEL(KTO)%XPAR_EFF_HEAT
XPAR_HC_FLOOR=>DATA_BEM_MODEL(KTO)%XPAR_HC_FLOOR
XPAR_TC_FLOOR=>DATA_BEM_MODEL(KTO)%XPAR_TC_FLOOR
XPAR_D_FLOOR=>DATA_BEM_MODEL(KTO)%XPAR_D_FLOOR
XPAR_QIN=>DATA_BEM_MODEL(KTO)%XPAR_QIN
XPAR_QIN_FRAD=>DATA_BEM_MODEL(KTO)%XPAR_QIN_FRAD
XPAR_SHGC=>DATA_BEM_MODEL(KTO)%XPAR_SHGC
XPAR_U_WIN=>DATA_BEM_MODEL(KTO)%XPAR_U_WIN
XPAR_GR=>DATA_BEM_MODEL(KTO)%XPAR_GR
XPAR_SHGC_SH=>DATA_BEM_MODEL(KTO)%XPAR_SHGC_SH
XPAR_FLOOR_HEIGHT=>DATA_BEM_MODEL(KTO)%XPAR_FLOOR_HEIGHT
XPAR_INF=>DATA_BEM_MODEL(KTO)%XPAR_INF
XPAR_SHADE=>DATA_BEM_MODEL(KTO)%XPAR_SHADE
XPAR_NATVENT=>DATA_BEM_MODEL(KTO)%XPAR_NATVENT
XPAR_F_WATER_COND=>DATA_BEM_MODEL(KTO)%XPAR_F_WATER_COND
XPAR_QIN_FLAT=>DATA_BEM_MODEL(KTO)%XPAR_QIN_FLAT
XPAR_HR_TARGET=>DATA_BEM_MODEL(KTO)%XPAR_HR_TARGET
XPAR_V_VENT=>DATA_BEM_MODEL(KTO)%XPAR_V_VENT
XPAR_CAP_SYS_HEAT=>DATA_BEM_MODEL(KTO)%XPAR_CAP_SYS_HEAT
XPAR_CAP_SYS_RAT=>DATA_BEM_MODEL(KTO)%XPAR_CAP_SYS_RAT
XPAR_T_ADP=>DATA_BEM_MODEL(KTO)%XPAR_T_ADP
XPAR_M_SYS_RAT=>DATA_BEM_MODEL(KTO)%XPAR_M_SYS_RAT
XPAR_COP_RAT=>DATA_BEM_MODEL(KTO)%XPAR_COP_RAT
XPAR_T_SIZE_MAX=>DATA_BEM_MODEL(KTO)%XPAR_T_SIZE_MAX
XPAR_T_SIZE_MIN=>DATA_BEM_MODEL(KTO)%XPAR_T_SIZE_MIN
IF (LHOOK) CALL DR_HOOK('MODD_DATA_BEM_N:DATA_BEM_GOTO_MODEL',1,ZHOOK_HANDLE)
!
END SUBROUTINE DATA_BEM_GOTO_MODEL
!
SUBROUTINE DATA_BEM_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DATA_BEM_N:DATA_BEM_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(DATA_BEM_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_TCOOL_TARGET)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_THEAT_TARGET)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_F_WASTE_CAN)  
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_EFF_HEAT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_HC_FLOOR)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_TC_FLOOR)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_D_FLOOR)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_QIN)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_QIN_FRAD)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_SHGC) 
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_U_WIN)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_GR)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_FLOOR_HEIGHT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_INF)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_F_WATER_COND)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_QIN_FLAT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_HR_TARGET)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_V_VENT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_CAP_SYS_HEAT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_CAP_SYS_RAT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_T_ADP)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_M_SYS_RAT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_COP_RAT)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_T_SIZE_MAX)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_T_SIZE_MIN)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_SHADE)
  NULLIFY(DATA_BEM_MODEL(J)%XPAR_NATVENT)
ENDDO
DATA_BEM_MODEL(:)%LDATA_TCOOL_TARGET = .FALSE.
DATA_BEM_MODEL(:)%LDATA_THEAT_TARGET = .FALSE. 
DATA_BEM_MODEL(:)%LDATA_F_WASTE_CAN  = .FALSE.   
DATA_BEM_MODEL(:)%LDATA_EFF_HEAT     = .FALSE.   
DATA_BEM_MODEL(:)%LDATA_HC_FLOOR     = .FALSE.     
DATA_BEM_MODEL(:)%LDATA_TC_FLOOR     = .FALSE.     
DATA_BEM_MODEL(:)%LDATA_D_FLOOR      = .FALSE. 
DATA_BEM_MODEL(:)%LDATA_QIN          = .FALSE.          
DATA_BEM_MODEL(:)%LDATA_QIN_FRAD     = .FALSE.     
DATA_BEM_MODEL(:)%LDATA_SHGC         = .FALSE.         
DATA_BEM_MODEL(:)%LDATA_U_WIN        = .FALSE.        
DATA_BEM_MODEL(:)%LDATA_GR           = .FALSE.           
DATA_BEM_MODEL(:)%LDATA_SHGC_SH      = .FALSE.
DATA_BEM_MODEL(:)%LDATA_FLOOR_HEIGHT = .FALSE. 
DATA_BEM_MODEL(:)%LDATA_INF          = .FALSE.  
DATA_BEM_MODEL(:)%LDATA_F_WATER_COND = .FALSE.  
DATA_BEM_MODEL(:)%LDATA_SHADE        = .FALSE.
DATA_BEM_MODEL(:)%LDATA_NATVENT      = .FALSE.
DATA_BEM_MODEL(:)%LDATA_V_VENT       = .FALSE.   
DATA_BEM_MODEL(:)%LDATA_QIN_FLAT     = .FALSE.     
DATA_BEM_MODEL(:)%LDATA_HR_TARGET    = .FALSE.    
DATA_BEM_MODEL(:)%LDATA_CAP_SYS_HEAT = .FALSE. 
DATA_BEM_MODEL(:)%LDATA_CAP_SYS_RAT  = .FALSE.  
DATA_BEM_MODEL(:)%LDATA_T_ADP        = .FALSE.        
DATA_BEM_MODEL(:)%LDATA_M_SYS_RAT    = .FALSE.    
DATA_BEM_MODEL(:)%LDATA_COP_RAT      = .FALSE.      
DATA_BEM_MODEL(:)%LDATA_T_SIZE_MAX   = .FALSE.    
DATA_BEM_MODEL(:)%LDATA_T_SIZE_MIN   = .FALSE.
DATA_BEM_MODEL(:)%NPAR_FLOOR_LAYER   =0

IF (LHOOK) CALL DR_HOOK("MODD_DATA_BEM_N:DATA_BEM_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE DATA_BEM_ALLOC
!
SUBROUTINE DATA_BEM_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DATA_BEM_N:DATA_BEM_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(DATA_BEM_MODEL)) DEALLOCATE(DATA_BEM_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_DATA_BEM_N:DATA_BEM_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE DATA_BEM_DEALLO
!
END MODULE MODD_DATA_BEM_n
