!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ####################
      MODULE MODD_DATA_COVER_n
!     ######################
!
!!****  *MODD_DATA_COVER_n* - declaration of correspondances between surface
!!                            classes and variables, for parameters that
!!                            can change as function of physical options
!!                            (GARDENs or not).
!!
!!    PURPOSE
!!    -------
!     Declaration of surface parameters
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	V. Masson    *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       09/2011
!
!*       0.   DECLARATIONS
!             ------------
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE DATA_COVER_t
!
!-----------------------------------------------------------------------------------------------------
!
REAL, DIMENSION(:),   POINTER :: XDATA_TOWN   ! artificial surfaces fraction
REAL, DIMENSION(:),   POINTER :: XDATA_NATURE ! natural and cul. fraction
REAL, DIMENSION(:),   POINTER :: XDATA_SEA    ! sea fraction
REAL, DIMENSION(:),   POINTER :: XDATA_WATER  ! inland water fraction
REAL, DIMENSION(:,:), POINTER :: XDATA_VEGTYPE! vegetation types fractions
REAL, DIMENSION(:),   POINTER :: XDATA_GARDEN ! garden fraction
REAL, DIMENSION(:),   POINTER :: XDATA_BLD    ! building fraction in
                                              ! artificial areas
REAL, DIMENSION(:),   POINTER :: XDATA_WALL_O_HOR  ! ratio of vert. surf.
!                                                  ! over hor. surf.
!
LOGICAL                           :: LGARDEN      ! T: define urban green areas
!                                                 ! F: no urban green areas
!
INTEGER :: NYEAR        ! current year for ecoclimap2
!
!-----------------------------------------------------------------------------------------------------
!
END TYPE DATA_COVER_t

TYPE(DATA_COVER_t), ALLOCATABLE, TARGET, SAVE :: DATA_COVER_MODEL(:)

REAL, POINTER, DIMENSION(:)   :: XDATA_TOWN=>NULL()
!$OMP THREADPRIVATE(XDATA_TOWN)
REAL, POINTER, DIMENSION(:)   :: XDATA_NATURE=>NULL()
!$OMP THREADPRIVATE(XDATA_NATURE)
REAL, POINTER, DIMENSION(:)   :: XDATA_SEA   =>NULL()
!$OMP THREADPRIVATE(XDATA_SEA   )
REAL, POINTER, DIMENSION(:)   :: XDATA_WATER =>NULL()
!$OMP THREADPRIVATE(XDATA_WATER )
REAL, POINTER, DIMENSION(:,:) :: XDATA_VEGTYPE=>NULL()
!$OMP THREADPRIVATE(XDATA_VEGTYPE)
REAL, POINTER, DIMENSION(:)   :: XDATA_GARDEN=>NULL()
!$OMP THREADPRIVATE(XDATA_GARDEN)
REAL, POINTER, DIMENSION(:)   :: XDATA_BLD   =>NULL()
!$OMP THREADPRIVATE(XDATA_BLD)
REAL, POINTER, DIMENSION(:)   :: XDATA_WALL_O_HOR   =>NULL()
!$OMP THREADPRIVATE(XDATA_WALL_O_HOR)
LOGICAL, POINTER :: LGARDEN=>NULL()
!$OMP THREADPRIVATE(LGARDEN)
INTEGER, POINTER :: NYEAR=>NULL()   ! current year for ecoclimap2
!$OMP THREADPRIVATE(NYEAR)

CONTAINS

SUBROUTINE DATA_COVER_GOTO_MODEL(KFROM, KTO, LKFROM)
LOGICAL, INTENT(IN) :: LKFROM
INTEGER, INTENT(IN) :: KFROM, KTO
REAL(KIND=JPRB) :: ZHOOK_HANDLE

!
! Save current state for allocated arrays
IF (LKFROM) THEN
DATA_COVER_MODEL(KFROM)%XDATA_TOWN=>XDATA_TOWN
DATA_COVER_MODEL(KFROM)%XDATA_NATURE=>XDATA_NATURE
DATA_COVER_MODEL(KFROM)%XDATA_SEA=>XDATA_SEA
DATA_COVER_MODEL(KFROM)%XDATA_WATER=>XDATA_WATER
DATA_COVER_MODEL(KFROM)%XDATA_VEGTYPE=>XDATA_VEGTYPE
DATA_COVER_MODEL(KFROM)%XDATA_GARDEN=>XDATA_GARDEN
DATA_COVER_MODEL(KFROM)%XDATA_BLD=>XDATA_BLD
DATA_COVER_MODEL(KFROM)%XDATA_WALL_O_HOR=>XDATA_WALL_O_HOR
ENDIF
!
! Current model is set to model KTO
IF (LHOOK) CALL DR_HOOK('MODD_DATA_COVER_N:DATA_COVER_GOTO_MODEL',0,ZHOOK_HANDLE)

XDATA_TOWN=>DATA_COVER_MODEL(KTO)%XDATA_TOWN
XDATA_NATURE=>DATA_COVER_MODEL(KTO)%XDATA_NATURE
XDATA_SEA=>DATA_COVER_MODEL(KTO)%XDATA_SEA
XDATA_WATER=>DATA_COVER_MODEL(KTO)%XDATA_WATER
XDATA_VEGTYPE=>DATA_COVER_MODEL(KTO)%XDATA_VEGTYPE
XDATA_GARDEN=>DATA_COVER_MODEL(KTO)%XDATA_GARDEN
XDATA_BLD=>DATA_COVER_MODEL(KTO)%XDATA_BLD
XDATA_WALL_O_HOR=>DATA_COVER_MODEL(KTO)%XDATA_WALL_O_HOR
LGARDEN=>DATA_COVER_MODEL(KTO)%LGARDEN
NYEAR=>DATA_COVER_MODEL(KTO)%NYEAR

IF (LHOOK) CALL DR_HOOK('MODD_DATA_COVER_N:DATA_COVER_GOTO_MODEL',1,ZHOOK_HANDLE)

END SUBROUTINE DATA_COVER_GOTO_MODEL

SUBROUTINE DATA_COVER_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DATA_COVER_N:DATA_COVER_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(DATA_COVER_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_TOWN)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_NATURE)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_SEA)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_WATER)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_VEGTYPE)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_GARDEN)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_BLD)
  NULLIFY(DATA_COVER_MODEL(J)%XDATA_WALL_O_HOR)
ENDDO
DATA_COVER_MODEL(:)%LGARDEN=.FALSE.
DATA_COVER_MODEL(:)%NYEAR=9999
IF (LHOOK) CALL DR_HOOK("MODD_DATA_COVER_N:DATA_COVER_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE DATA_COVER_ALLOC

SUBROUTINE DATA_COVER_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DATA_COVER_N:DATA_COVER_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(DATA_COVER_MODEL)) DEALLOCATE(DATA_COVER_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_DATA_COVER_N:DATA_COVER_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE DATA_COVER_DEALLO

END MODULE MODD_DATA_COVER_n

