!SURFEX_LIC Copyright 1994-2014 Meteo-France 
!SURFEX_LIC This is part of the SURFEX software governed by the CeCILL-C  licence
!SURFEX_LIC version 1. See LICENSE, CeCILL-C_V1-en.txt and CeCILL-C_V1-fr.txt
!SURFEX_LIC for details. version 1.
!     ######################
      MODULE MODD_DIAG_OCEAN_n
!     ######################
!
!!****  *MODD_DIAG_OCEAN - declaration of diagnostics for ocean
!!
!!    PURPOSE
!!    -------
!
!!
!!**  IMPLICIT ARGUMENTS
!!    ------------------
!!      None 
!!
!!    REFERENCE
!!    ---------
!!
!!    AUTHOR
!!    ------
!!	C. Lebeaupin Brossier   *Meteo France*
!!
!!    MODIFICATIONS
!!    -------------
!!      Original       02/2008
!
!*       0.   DECLARATIONS
!             ------------
!
!
!
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK
USE PARKIND1  ,ONLY : JPRB
!
IMPLICIT NONE

TYPE DIAG_OCEAN_t
!------------------------------------------------------------------------------
!
  LOGICAL :: LDIAG_OCEAN                    ! flag for ocean variables
!
!* averaged variables
!
  REAL, POINTER, DIMENSION(:)   :: XTOCMOY  ! mean temperature in CMO (C)
  REAL, POINTER, DIMENSION(:)   :: XSOCMOY  ! mean salinity in CMO (psu)
  REAL, POINTER, DIMENSION(:)   :: XUOCMOY  ! mean zonal current in CMO (m/s)
  REAL, POINTER, DIMENSION(:)   :: XVOCMOY  ! mean meridian current in CMO (m/s)
  REAL, POINTER, DIMENSION(:)   :: XDOCMOY  ! mean density in CMO (kg/m3)
!------------------------------------------------------------------------------
!

END TYPE DIAG_OCEAN_t

TYPE(DIAG_OCEAN_t), ALLOCATABLE, TARGET, SAVE :: DIAG_OCEAN_MODEL(:)

LOGICAL, POINTER :: LDIAG_OCEAN=>NULL()
!$OMP THREADPRIVATE(LDIAG_OCEAN)
REAL, POINTER, DIMENSION(:)   :: XTOCMOY=>NULL()
!$OMP THREADPRIVATE(XTOCMOY)
REAL, POINTER, DIMENSION(:)   :: XSOCMOY=>NULL()
!$OMP THREADPRIVATE(XSOCMOY)
REAL, POINTER, DIMENSION(:)   :: XUOCMOY=>NULL()
!$OMP THREADPRIVATE(XUOCMOY)
REAL, POINTER, DIMENSION(:)   :: XVOCMOY=>NULL()
!$OMP THREADPRIVATE(XVOCMOY)
REAL, POINTER, DIMENSION(:)   :: XDOCMOY=>NULL()
!$OMP THREADPRIVATE(XDOCMOY)


CONTAINS

SUBROUTINE DIAG_OCEAN_GOTO_MODEL(KFROM, KTO, LKFROM)
LOGICAL, INTENT(IN) :: LKFROM
INTEGER, INTENT(IN) :: KFROM, KTO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
!
! Save current state for allocated arrays
IF (LKFROM) THEN
DIAG_OCEAN_MODEL(KFROM)%XTOCMOY=>XTOCMOY
DIAG_OCEAN_MODEL(KFROM)%XSOCMOY=>XSOCMOY
DIAG_OCEAN_MODEL(KFROM)%XUOCMOY=>XUOCMOY
DIAG_OCEAN_MODEL(KFROM)%XVOCMOY=>XVOCMOY
DIAG_OCEAN_MODEL(KFROM)%XDOCMOY=>XDOCMOY
ENDIF

!
! Current model is set to model KTO
IF (LHOOK) CALL DR_HOOK('MODD_DIAG_OCEAN_N:DIAG_OCEAN_GOTO_MODEL',0,ZHOOK_HANDLE)
LDIAG_OCEAN=>DIAG_OCEAN_MODEL(KTO)%LDIAG_OCEAN
XTOCMOY=>DIAG_OCEAN_MODEL(KTO)%XTOCMOY
XSOCMOY=>DIAG_OCEAN_MODEL(KTO)%XSOCMOY
XUOCMOY=>DIAG_OCEAN_MODEL(KTO)%XUOCMOY
XVOCMOY=>DIAG_OCEAN_MODEL(KTO)%XVOCMOY
XDOCMOY=>DIAG_OCEAN_MODEL(KTO)%XDOCMOY
IF (LHOOK) CALL DR_HOOK('MODD_DIAG_OCEAN_N:DIAG_OCEAN_GOTO_MODEL',1,ZHOOK_HANDLE)

END SUBROUTINE DIAG_OCEAN_GOTO_MODEL

SUBROUTINE DIAG_OCEAN_ALLOC(KMODEL)
INTEGER, INTENT(IN) :: KMODEL
INTEGER :: J
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_OCEAN_N:DIAG_OCEAN_ALLOC",0,ZHOOK_HANDLE)
ALLOCATE(DIAG_OCEAN_MODEL(KMODEL))
DO J=1,KMODEL
  NULLIFY(DIAG_OCEAN_MODEL(J)%XTOCMOY)
  NULLIFY(DIAG_OCEAN_MODEL(J)%XSOCMOY)
  NULLIFY(DIAG_OCEAN_MODEL(J)%XUOCMOY)
  NULLIFY(DIAG_OCEAN_MODEL(J)%XVOCMOY)
  NULLIFY(DIAG_OCEAN_MODEL(J)%XDOCMOY)
ENDDO
DIAG_OCEAN_MODEL(:)%LDIAG_OCEAN=.FALSE.
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_OCEAN_N:DIAG_OCEAN_ALLOC",1,ZHOOK_HANDLE)
END SUBROUTINE DIAG_OCEAN_ALLOC

SUBROUTINE DIAG_OCEAN_DEALLO
REAL(KIND=JPRB) :: ZHOOK_HANDLE
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_OCEAN_N:DIAG_OCEAN_DEALLO",0,ZHOOK_HANDLE)
IF (ALLOCATED(DIAG_OCEAN_MODEL)) DEALLOCATE(DIAG_OCEAN_MODEL)
IF (LHOOK) CALL DR_HOOK("MODD_DIAG_OCEAN_N:DIAG_OCEAN_DEALLO",1,ZHOOK_HANDLE)
END SUBROUTINE DIAG_OCEAN_DEALLO

END MODULE MODD_DIAG_OCEAN_n
